==> mingw-w64-graphviz-8.1.0-1.src.tar.zst: graphviz-8.1.0/windows/include/config.h <==
/* manually generated configuration for Windows */

/* Include generated files */
#include "builddate.h"
#include "version.h"

/* Define to one of `_getb67', `GETB67', `getb67' for Cray-2 and Cray-YMP
   systems. This function is required for `alloca.c' support on those systems.
   */
/* #undef CRAY_STACKSEG_END */

/* Define for Darwin-style shared library names. */
/* #undef DARWIN_DYLIB */

/* Default DPI. */
#define DEFAULT_DPI 96

/* Define if you want DIGCOLA */
#define DIGCOLA 1

/* Filename for plugin configuration file. */
#define GVPLUGIN_CONFIG_FILE "config6"

/* Compatibility version number for plugins. */
#define GVPLUGIN_VERSION 6

/* Define if you want on-demand plugin loading */
#define ENABLE_LTDL 1

/* Define if you have the ann library */
#define HAVE_ANN 1

/* Define if you have the DevIL library */
/* #undef HAVE_DEVIL */

/* Define to 1 if you have the <dlfcn.h> header file. */
/* #undef HAVE_DLFCN_H */

/* Define to 1 if you have the `dl_iterate_phdr` function */
/* #undef HAVE_DL_ITERATE_PHDR */

/* Define to 1 if you have the `drand48' function. */
/* #undef HAVE_DRAND48 */

/* Define if you have the expat library */
#define HAVE_EXPAT 1

/* Define to 1 if you have the <expat.h> header file. */
#define HAVE_EXPAT_H 1

/* Define if you have the freetype2 library */
#define HAVE_FREETYPE2 1

/* Define if you have the GDI+ framework for Windows */
/* #undef HAVE_GDIPLUS */

/* Define if the GD library has the GD_FONTCONFIG feature */
#define HAVE_GD_FONTCONFIG 1

/* Define if the GD library has the GD_FREETYPE feature */
#define HAVE_GD_FREETYPE 1

/* Define if the GD library has the GD_GIF feature */
#define HAVE_GD_GIF 1

/* Define if the GD library has the GD_JPEG feature */
#define HAVE_GD_JPEG 1

/* Define if the GD library has the GD_PNG feature */
#define HAVE_GD_PNG 1

/* Define if the GD library supports XPM */
/* #undef HAVE_GD_XPM */

/* Define if you have the glade library */
#define HAVE_GLADE 1

/* Define if you have the gs library */
/* #undef HAVE_GS */

/* Define if you have the gtk library */
/* #undef HAVE_GTK */

/* Define if you have the gtkgl library */
/* #undef HAVE_GTKGL */

/* Define if you have the gts library */
/* #undef HAVE_GTS */

/* Define to 1 if you have the <IL/il.h> header file. */
/* #undef HAVE_IL_IL_H */

/* Define if you have the lasi library */
/* #undef HAVE_LASI */

/* Define if either internal or external GD library is availabel */
#define HAVE_LIBGD 1

/* Define if you have the JPEG library */
#define HAVE_LIBJPEG 1

/* Define if you have the PNG library */
#define HAVE_LIBPNG 1

/* Define if you have the Z library */
#define HAVE_LIBZ 1

/* Define to 1 if you have the `lrand48' function. */
/* #undef HAVE_LRAND48 */

/* Define if you have the pangocairo library */
#define HAVE_PANGOCAIRO 1

/* Define to 1 if you have the `pango_fc_font_lock_face' function. */
/* #undef HAVE_PANGO_FC_FONT_LOCK_FACE */

/* Define to 1 if you have the `pango_fc_font_unlock_face' function. */
/* #undef HAVE_PANGO_FC_FONT_UNLOCK_FACE */

/* Define if you have the Quartz framework for Mac OS X */
/* #undef HAVE_QUARTZ */

/* Define if you have the rsvg library */
#define HAVE_RSVG 1

/* Define to 1 if you have the <search.h> header file. */
#define HAVE_SEARCH_H 1

/* Define to 1 if you have the `memrchr' function. */
/* #undef HAVE_MEMRCHR */

/* Define to 1 if you have the `setenv' function. */
/* #undef HAVE_SETENV */

/* Define to 1 if you have the `setmode' function. */
#define HAVE_SETMODE 1

/* Define if libm provides a *working* sincos function */
/* #undef HAVE_SINCOS */

/* Define to 1 if you have the `srand48' function. */
/* #undef HAVE_SRAND48 */

/* Define to 1 if you have the <sys/inotify.h> header file. */
/* #undef HAVE_SYS_INOTIFY_H */

/* Define to 1 if you have the <sys/ioctl.h> header file. */
/* #undef HAVE_SYS_IOCTL_H */

/* Define to 1 if you have the <sys/mman.h> header file. */
/* #undef HAVE_SYS_MMAN_H */

/* Define to 1 if you have the <sys/select.h> header file. */
/* #undef HAVE_SYS_SELECT_H */

/* Define to 1 if you have the <sys/stat.h> header file. */
#define HAVE_SYS_STAT_H 1

/* Define to 1 if you have the <sys/time.h> header file. */
#define HAVE_SYS_TIME_H 1

/* Define to 1 if you have the <sys/types.h> header file. */
#define HAVE_SYS_TYPES_H 1

/* Define if you have the tcl library */
/* #undef HAVE_TCL */

/* Define to 1 if you have the <tkInt.h> header file. */
/* #undef HAVE_TKINT_H */

/* Define to 1 if you have the <tk.h> header file. */
/* #undef HAVE_TK_H */

/* Define if triangle.[ch] are available. */
/* #undef HAVE_TRIANGLE */

/* Define to 1 if you have the <X11/Intrinsic.h> header file. */
/* #undef HAVE_X11_INTRINSIC_H */

/* Define to 1 if you have the <X11/Xaw/Text.h> header file. */
/* #undef HAVE_X11_XAW_TEXT_H */

/* Define if you want IPSEPCOLA */
/* #undef IPSEPCOLA */
#define IPSEPCOLA 1
/* Define if no fpu error exception handling is required. */
#define NO_FPERR 1

/* Define if you want ORTHO */
/* #undef ORTHO */
#define ORTHO 1

/* Define to the address where bug reports for this package should be sent. */
#define PACKAGE_BUGREPORT "https://gitlab.com/graphviz/graphviz/-/issues"

/* Define to the full name of this package. */
#define PACKAGE_NAME "graphviz"

/* Define to the full name and version of this package. */
#define PACKAGE_STRING VERSION "(" BUILDDATE ")"

/* Define to the one symbol short name of this package. */
#define PACKAGE_TARNAME "graphviz"

/* Define to the home page for this package. */
#define PACKAGE_URL ""

/* Define to the version of this package. */
#define PACKAGE_VERSION VERSION

/* Define if you want SFDP */
#define SFDP 1
/* #undef SFDP */

/* Define if you want CGRAPH */
#define WITH_CGRAPH 1

/* Define to 1 if `lex' declares `yytext' as a `char *' by default, not a
   `char[]'. */
/* #undef YYTEXT_POINTER */

/* Define to `int' if <sys/types.h> does not define. */
/* #undef pid_t */

/* Define to `SSIZE_T' if <sys/types.h> does not define. */
#include <BaseTsd.h>
typedef SSIZE_T ssize_t;

==> mingw-w64-graphviz-12.1.2-2.src.tar.zst: graphviz-12.1.2/windows/include/config.h <==
/* manually generated configuration for Windows */

/* Include generated files */
#include "builddate.h"
#include "version.h"

/* Define to one of `_getb67', `GETB67', `getb67' for Cray-2 and Cray-YMP
   systems. This function is required for `alloca.c' support on those systems.
   */
/* #undef CRAY_STACKSEG_END */

/* Define for Darwin-style shared library names. */
/* #undef DARWIN_DYLIB */

/* Default DPI. */
#define DEFAULT_DPI 96

/* Define if you want DIGCOLA */
#define DIGCOLA 1

/* Filename for plugin configuration file. */
#define GVPLUGIN_CONFIG_FILE "config6"

/* Compatibility version number for plugins. */
#define GVPLUGIN_VERSION 6

/* Define if you want on-demand plugin loading */
#define ENABLE_LTDL 1

/* Define if you have the DevIL library */
/* #undef HAVE_DEVIL */

/* Define to 1 if you have the <dlfcn.h> header file. */
/* #undef HAVE_DLFCN_H */

/* Define to 1 if you have the `dl_iterate_phdr` function */
/* #undef HAVE_DL_ITERATE_PHDR */

/* Define to 1 if you have the `drand48' function. */
/* #undef HAVE_DRAND48 */

/* Define to 1 if you have the `inotify_init1' function. */
/* #undef HAVE_INOTIFY_INIT1 */

/* Define if you have the expat library */
#define HAVE_EXPAT 1

/* Define to 1 if you have the <expat.h> header file. */
#define HAVE_EXPAT_H 1

/* Define if you have the GDI+ framework for Windows */
/* #undef HAVE_GDIPLUS */

/* Define if the GD library has the GD_FONTCONFIG feature */
#define HAVE_GD_FONTCONFIG 1

/* Define if the GD library has the GD_FREETYPE feature */
#define HAVE_GD_FREETYPE 1

/* Define if the GD library has the GD_GIF feature */
#define HAVE_GD_GIF 1

/* Define if the GD library has the GD_JPEG feature */
#define HAVE_GD_JPEG 1

/* Define if the GD library has the GD_PNG feature */
#define HAVE_GD_PNG 1

/* Define if the GD library supports XPM */
/* #undef HAVE_GD_XPM */

/* Define if you have the gs library */
/* #undef HAVE_GS */

/* Define if you have the gtk library */
/* #undef HAVE_GTK */

/* Define if you have the gtkgl library */
/* #undef HAVE_GTKGL */

/* Define if you have the gts library */
/* #undef HAVE_GTS */

/* Define to 1 if you have the <IL/il.h> header file. */
/* #undef HAVE_IL_IL_H */

/* Define if you have the lasi library */
/* #undef HAVE_LASI */

/* Define if either internal or external GD library is availabel */
#define HAVE_LIBGD 1

/* Define if you have the JPEG library */
#define HAVE_LIBJPEG 1

/* Define if you have the PNG library */
#define HAVE_LIBPNG 1

/* Define if you have the Z library */
#define HAVE_LIBZ 1

/* Define to 1 if you have the `lrand48' function. */
/* #undef HAVE_LRAND48 */

/* Define if you have the pangocairo library */
#define HAVE_PANGOCAIRO 1

/* Define to 1 if you have the `pango_fc_font_lock_face' function. */
/* #undef HAVE_PANGO_FC_FONT_LOCK_FACE */

/* Define to 1 if you have the <search.h> header file. */
#define HAVE_SEARCH_H 1

/* Define to 1 if you have the `memrchr' function. */
/* #undef HAVE_MEMRCHR */

/* Define to 1 if you have the `setenv' function. */
/* #undef HAVE_SETENV */

/* Define to 1 if you have the `setmode' function. */
#define HAVE_SETMODE 1

/* Define to 1 if you have the `srand48' function. */
/* #undef HAVE_SRAND48 */

/* Define to 1 if you have the <sys/inotify.h> header file. */
/* #undef HAVE_SYS_INOTIFY_H */

/* Define to 1 if you have the <sys/ioctl.h> header file. */
/* #undef HAVE_SYS_IOCTL_H */

/* Define to 1 if you have the <sys/mman.h> header file. */
/* #undef HAVE_SYS_MMAN_H */

/* Define to 1 if you have the <sys/select.h> header file. */
/* #undef HAVE_SYS_SELECT_H */

/* Define to 1 if you have the <sys/time.h> header file. */
#define HAVE_SYS_TIME_H 1

/* Define to 1 if you have the <sys/types.h> header file. */
#define HAVE_SYS_TYPES_H 1

/* Define if you have the tcl library */
/* #undef HAVE_TCL */

/* Define if triangle.[ch] are available. */
/* #undef HAVE_TRIANGLE */

/* Define if you want IPSEPCOLA */
/* #undef IPSEPCOLA */
#define IPSEPCOLA 1
/* Define if no fpu error exception handling is required. */
#define NO_FPERR 1

/* Define if you want ORTHO */
/* #undef ORTHO */
#define ORTHO 1

/* Define to the address where bug reports for this package should be sent. */
#define PACKAGE_BUGREPORT "https://gitlab.com/graphviz/graphviz/-/issues"

/* Define to the full name of this package. */
#define PACKAGE_NAME "graphviz"

/* Define to the full name and version of this package. */
#define PACKAGE_STRING VERSION "(" BUILDDATE ")"

/* Define to the one symbol short name of this package. */
#define PACKAGE_TARNAME "graphviz"

/* Define to the home page for this package. */
#define PACKAGE_URL ""

/* Define to the version of this package. */
#define PACKAGE_VERSION VERSION

/* Define if you want SFDP */
#define SFDP 1
/* #undef SFDP */

/* Define if you want CGRAPH */
#define WITH_CGRAPH 1

/* Define to `int' if <sys/types.h> does not define. */
/* #undef pid_t */

/* Define to `SSIZE_T' if <sys/types.h> does not define. */
#include <BaseTsd.h>
typedef SSIZE_T ssize_t;
